@@ -25,7 +25,7 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  *
- * $Id: gedit-app.c 6116 2008-01-24 22:15:19Z pborelli $
+ * $Id: gedit-app.c 6498 2008-09-07 13:50:57Z pborelli $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -33,6 +33,7 @@
 #endif
 
 #include <string.h>
+#include <unistd.h>
 
 #include <glib/gi18n.h>
 
@@ -208,7 +209,7 @@ load_page_setup (GeditApp *app)
 		if (error->domain != G_FILE_ERROR ||
 		    error->code != G_FILE_ERROR_NOENT)
 		{
-			g_warning (error->message);
+			g_warning ("%s", error->message);
 		}
 
 		g_error_free (error);
@@ -237,7 +238,7 @@ save_page_setup (GeditApp *app)
 				&error);
 	if (error)
 	{
-		g_warning (error->message);
+		g_warning ("%s", error->message);
 		g_error_free (error);
 	}
 
@@ -280,7 +281,7 @@ load_print_settings (GeditApp *app)
 		if (error->domain != G_FILE_ERROR ||
 		    error->code != G_FILE_ERROR_NOENT)
 		{
-			g_warning (error->message);
+			g_warning ("%s", error->message);
 		}
 
 		g_error_free (error);
@@ -309,7 +310,7 @@ save_print_settings (GeditApp *app)
 				    &error);
 	if (error)
 	{
-		g_warning (error->message);
+		g_warning ("%s", error->message);
 		g_error_free (error);
 	}
 
@@ -846,7 +847,7 @@ _gedit_app_set_default_page_setup (GeditApp     *app,
 	if (app->priv->page_setup != NULL)
 		g_object_unref (app->priv->page_setup);
 
-	app->priv->page_setup = page_setup;
+	app->priv->page_setup = g_object_ref (page_setup);
 }
 
 /* Returns a copy */
@@ -871,6 +872,6 @@ _gedit_app_set_default_print_settings (GeditApp         *app,
 	if (app->priv->print_settings != NULL)
 		g_object_unref (app->priv->print_settings);
 
-	app->priv->print_settings = settings;
+	app->priv->print_settings = g_object_ref (settings);
 }
 
