@@ -25,7 +25,7 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  *
- * $Id: gedit-plugin.h 5666 2007-06-29 19:52:25Z sfre $
+ * $Id: gedit-plugin.h 6493 2008-09-06 14:51:52Z jessevdk $
  */
 
 #ifndef __GEDIT_PLUGIN_H__
@@ -112,10 +112,10 @@ gboolean	 gedit_plugin_is_configurable	(GeditPlugin *plugin);
 GtkWidget	*gedit_plugin_create_configure_dialog		
 						(GeditPlugin *plugin);
 
-/*
- * Utility macro used to register plugins
+/**
+ * GEDIT_PLUGIN_REGISTER_TYPE_WITH_CODE(PluginName, plugin_name, CODE):
  *
- * use: GEDIT_PLUGIN_REGISTER_TYPE_WITH_CODE(PluginName, plugin_name, CODE)
+ * Utility macro used to register plugins with additional code.
  */
 #define GEDIT_PLUGIN_REGISTER_TYPE_WITH_CODE(PluginName, plugin_name, CODE)	\
 										\
@@ -169,18 +169,18 @@ register_gedit_plugin (GTypeModule *module)					\
 	return plugin_name##_type;						\
 }
 
-/*
- * Utility macro used to register plugins
- *
- * use: GEDIT_PLUGIN_REGISTER_TYPE(PluginName, plugin_name)
+/**
+ * GEDIT_PLUGIN_REGISTER_TYPE(PluginName, plugin_name):
+ * 
+ * Utility macro used to register plugins.
  */
 #define GEDIT_PLUGIN_REGISTER_TYPE(PluginName, plugin_name)			\
 	GEDIT_PLUGIN_REGISTER_TYPE_WITH_CODE(PluginName, plugin_name, ;)
 
-/*
- * Utility macro used to register gobject types in plugins with additional code
+/**
+ * GEDIT_PLUGIN_DEFINE_TYPE_WITH_CODE(ObjectName, object_name, PARENT_TYPE, CODE):
  *
- * use: GEDIT_PLUGIN_DEFINE_TYPE_WITH_CODE(ObjectName, object_name, PARENT_TYPE, CODE)
+ * Utility macro used to register gobject types in plugins with additional code.
  */
 #define GEDIT_PLUGIN_DEFINE_TYPE_WITH_CODE(ObjectName, object_name, PARENT_TYPE, CODE)	\
 										\
@@ -230,14 +230,32 @@ object_name##_register_type (GTypeModule *module)					\
 	return g_define_type_id;						\
 }
 
-/*
- * Utility macro used to register gobject types in plugins
+/**
+ * GEDIT_PLUGIN_DEFINE_TYPE(ObjectName, object_name, PARENT_TYPE):
  *
- * use: GEDIT_PLUGIN_DEFINE_TYPE(ObjectName, object_name, PARENT_TYPE)
+ * Utility macro used to register gobject types in plugins.
  */
 #define GEDIT_PLUGIN_DEFINE_TYPE(ObjectName, object_name, PARENT_TYPE)		\
 	GEDIT_PLUGIN_DEFINE_TYPE_WITH_CODE(ObjectName, object_name, PARENT_TYPE, ;)
 
+/**
+ * GEDIT_PLUGIN_IMPLEMENT_INTERFACE(TYPE_IFACE, iface_init):
+ *
+ * Utility macro used to register interfaces for gobject types in plugins.
+ */
+#define GEDIT_PLUGIN_IMPLEMENT_INTERFACE(object_name, TYPE_IFACE, iface_init)	\
+	const GInterfaceInfo object_name##_interface_info = 			\
+	{ 									\
+		(GInterfaceInitFunc) iface_init,				\
+		NULL, 								\
+		NULL								\
+	};									\
+										\
+	g_type_module_add_interface (module, 					\
+				     g_define_type_id, 				\
+				     TYPE_IFACE, 				\
+				     &object_name##_interface_info);		\
+
 G_END_DECLS
 
 #endif  /* __GEDIT_PLUGIN_H__ */
