@@ -25,7 +25,7 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  *
- * $Id: gedit.c 6547 2008-09-16 20:44:53Z pborelli $
+ * $Id: gedit.c 6584 2008-10-18 10:46:04Z pborelli $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -54,6 +54,7 @@
 
 #include "bacon-message-connection.h"
 #include "eggsmclient.h"
+#include "eggdesktopfile.h"
 
 static guint32 startup_timestamp = 0;
 static BaconMessageConnection *connection;
@@ -480,6 +481,8 @@ main (int argc, char *argv[])
 		return 1;
 	}
 
+	g_option_context_free (context);
+
 	gedit_debug_message (DEBUG_APP, "Create bacon connection");
 
 	connection = bacon_message_connection_new ("gedit");
@@ -522,8 +525,8 @@ main (int argc, char *argv[])
 	gtk_icon_theme_append_search_path (gtk_icon_theme_get_default (),
 					   GEDIT_ICONDIR);
 
-	/* Set default icon */
-	gtk_window_set_default_icon_name ("accessories-text-editor");
+	/* Set the associated .desktop file */
+	egg_set_desktop_file (DATADIR "/applications/gedit.desktop");
 
 	/* Load user preferences */
 	gedit_debug_message (DEBUG_APP, "Init prefs manager");
